@@ -6,7 +6,8 @@ requires 'slice';
 has 'component' => (
     is => 'rw',
     isa => 'Graphics::Primitive::TextBox',
-    required => 1
+    required => 1,
+    weak_ref => 1
 );
 has 'height' => (
     is => 'rw',
@@ -81,4 +82,4 @@ Cory Watson, C<< <gphat@cpan.org> >>
 Copyright 2008-2010 by Cory G Watson.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
\ No newline at end of file
+under the same terms as Perl itself.
